Coverage for src/atlus/__init__.py: 100%

1"""`atlus` is a Python package to convert raw address and phone number strings into the OSM format.

2 It's designed to be used with US and Canadian phone numbers and addresses.

3

4```python

5>>> import atlus

6>>> atlus.abbrs("St. Francis")

7# "Saint Francis"

8>>> atlus.get_address("789 Oak Dr, Smallville California, 98765")[0]

9# {"addr:housenumber": "789", "addr:street": "Oak Drive", "addr:city": "Smallville", "addr:state": "CA", "addr:postcode": "98765"}

10>>> atlus.get_phone("(202) 900-9019")

11# "+1 202-900-9019"

12```

13

14"""

15

16# SPDX-FileCopyrightText: 2024-present Will <wahubsch@gmail.com>

17#

18# SPDX-License-Identifier: MIT

19

20 from .atlus import (

21 get_address,

22 get_phone,

23 abbrs,

24 get_title,

25 mc_replace,

26 us_replace,

27 ord_replace,

28 remove_br_unicode,

29)

30 from . import atlus

31 from . import resources

32

33 __all__ = [

34 "get_address",

35 "get_phone",

36 "abbrs",

37 "get_title",

38 "mc_replace",

39 "us_replace",

40 "ord_replace",

41 "remove_br_unicode",

42 "atlus",

43 "resources",

44]